#!/usr/bin/python

import sys
import charmhelpers.core.hookenv as hookenv
import charmhelpers.core.host as host
import charmhelpers.fetch as fetch
from charmhelpers.core.hookenv import UnregisteredHookError
import os

KDUMP_CONF = '/etc/default/kdump-tools'
_EBAD = -1

hooks = hookenv.Hooks()


@hooks.hook('install')
def install():
    fetch.apt_update(fatal=True)
    fetch.apt_install(["linux-crashdump"], fatal=True)


@hooks.hook('upgrade-charm')
@hooks.hook('config-changed')
@hooks.hook('master-relation-changed')
@hooks.hook('master-relation-departed')
@host.restart_on_change({KDUMP_CONF: ['crashdump']})
def enable_kdump():
    firstpass = False
    if not os.path.exists("{}.ref".format(KDUMP_CONF)):
        os.rename("{}".format(KDUMP_CONF), "{}.ref".format(KDUMP_CONF))
        firstpass = True
    with open("{}.ref".format(KDUMP_CONF), "r") as orig:
        try:
            with open("{}".format(KDUMP_CONF), "w") as new_conf:
                for line in orig.readlines():
                    if line.find('USE_KDUMP') == 0:
                        new_conf.write("{}".format('USE_KDUMP=1\n'))
                    else:
                        new_conf.write("{}".format(line))
            if firstpass:
                os.system("juju-reboot")
        except IOError as err:
            print(("User does not have the privilege "
                   "to change this file\t{}").format(err))
            return _EBAD


if __name__ == '__main__':
    try:
        hooks.execute(sys.argv)
    except UnregisteredHookError as e:
        hookenv.log('Unknown hook {} - skipping.'.format(e))
