#!/usr/bin/python3

# This amulet code is to test the crashdump charm.

import amulet

# The number of seconds to wait for Juju to set up the environment.
seconds = 900

d = amulet.Deployment(series = 'trusty')
# Add the crashdump charm to the deployment.
d.add('crashdump')
# Add the mysql charm to the deployment as 
# Principal service
d.add('mysql')

# Relate the crashdump and mysql charms.
d.relate('crashdump:juju-info', 'mysql:juju-info')

# Deploy the environment and wait for it to setup.
try:
    d.setup(timeout=seconds)
    d.sentry.wait(seconds)
except amulet.helpers.TimeoutError:
    message = 'The environment did not setup in %d seconds.' % seconds
    # The SKIP status enables skip or fail the test based on configuration.
    amulet.raise_status(amulet.SKIP, msg=message)
except:
    raise

# Unable to get the sentry unit for crashdump because it is a subordinate.

# Get the sentry unit for mysql.
mysql_unit = d.sentry.unit['mysql/0']

# Create a command to check the crashdump service.
command = 'sudo kdump-config show'
print(command)
# Run the command to see if kdump is ready to dump
output, code = mysql_unit.run(command)
print(output)
if code != 0 or output.find('current state:    ready to kdump') == -1:
    message = 'The crashdump service is not running on the mysql unit.'
    print(message)
    amulet.raise_status(amulet.FAIL, msg=message)

print('The crashdump deploy test completed successfully.')
